@@ -1,10 +1,9 @@
-__version__ = '0.0.2'
+__version__ = '0.0.4'
 __author__ = 'Xiang Wang'
 
 # List maintainers here
 __maintainers__ = [
-    'Xiang Wang',
-    'ChenJie Shen'
+    'Xiang Wang'
 ]
 
 __all__ = [
