@@ -2,16 +2,16 @@ from ark_nlp.dataset.base._dataset import *
 
 from ark_nlp.dataset.base._sentence_classification_dataset import SentenceClassificationDataset
 from ark_nlp.dataset.base._sentence_classification_dataset import SentenceClassificationDataset as SCDataset
-from ark_nlp.dataset.base._sentence_classification_dataset import PairSentenceClassificationDataset
-from ark_nlp.dataset.base._sentence_classification_dataset import PairSentenceClassificationDataset as PSCDataset
+from ark_nlp.dataset.base._sentence_classification_dataset import PairMergeSentenceClassificationDataset
+from ark_nlp.dataset.base._sentence_classification_dataset import PairMergeSentenceClassificationDataset as PMSCDataset
+from ark_nlp.dataset.base._sentence_classification_dataset import TwinTowersSentenceClassificationDataset
+from ark_nlp.dataset.base._sentence_classification_dataset import TwinTowersSentenceClassificationDataset as TTSCDataset
 
-from ark_nlp.dataset.base._token_classification_dataset import BIOTokenClassificationDataset
-from ark_nlp.dataset.base._token_classification_dataset import BIOTokenClassificationDataset as BIOTCDataset
+from ark_nlp.dataset.base._token_classification_dataset import TokenClassificationDataset
 
-from ark_nlp.dataset.casrel_relation_extraction_dataset import CasRelREDataset
 from ark_nlp.dataset.text_classification_dataset import TCDataset
 from ark_nlp.dataset.text_match_dataset import TMDataset
 from ark_nlp.dataset.bio_named_entity_recognition_dataset import BIONERDataset
 from ark_nlp.dataset.biaffine_named_entity_recognition_dataset import BiaffineNERDataset
 from ark_nlp.dataset.span_named_entity_recognition_dataset import SpanNERDataset
-from ark_nlp.dataset.global_pointer_named_entity_recognition_dataset import GlobalPointerNERDataset
\ No newline at end of file
+from ark_nlp.dataset.global_pointer_named_entity_recognition_dataset import GlobalPointerNERDataset
