@@ -9,8 +9,3 @@ from ark_nlp.factory.task.named_entity_recognition import CRFNERTask
 from ark_nlp.factory.task.named_entity_recognition import BiaffineNERTask
 from ark_nlp.factory.task.named_entity_recognition import GlobalPointerNERTask
 from ark_nlp.factory.task.named_entity_recognition import SpanNERTask
-
-from ark_nlp.factory.task.casrel_relation_extraction import CasrelRETask
-
-from ark_nlp.factory.task.ema import EMATCTask
-from ark_nlp.factory.task.ema import EMANERTask
\ No newline at end of file
